package com.mysql.jdbc;

import java.sql.SQLException;
import java.util.List;

/* JADX INFO: Access modifiers changed from: package-private */
/* compiled from: CharsetMapping.java */
/* loaded from: com_mysql_jdbc.jar:com/mysql/jdbc/VersionedStringProperty.class */
public class VersionedStringProperty {
    int majorVersion;
    int minorVersion;
    int subminorVersion;
    boolean preferredValue;
    String propertyInfo;

    /* JADX INFO: Access modifiers changed from: package-private */
    public VersionedStringProperty(String property) {
        this.preferredValue = false;
        String property2 = property.trim();
        if (property2.startsWith("*")) {
            property2 = property2.substring(1);
            this.preferredValue = true;
        }
        if (property2.startsWith(">")) {
            String property3 = property2.substring(1);
            int charPos = 0;
            while (charPos < property3.length()) {
                char c = property3.charAt(charPos);
                if (!Character.isWhitespace(c) && !Character.isDigit(c) && c != '.') {
                    break;
                } else {
                    charPos++;
                }
            }
            String versionInfo = property3.substring(0, charPos);
            List versionParts = StringUtils.split(versionInfo, ".", true);
            this.majorVersion = Integer.parseInt(versionParts.get(0).toString());
            if (versionParts.size() > 1) {
                this.minorVersion = Integer.parseInt(versionParts.get(1).toString());
            } else {
                this.minorVersion = 0;
            }
            if (versionParts.size() > 2) {
                this.subminorVersion = Integer.parseInt(versionParts.get(2).toString());
            } else {
                this.subminorVersion = 0;
            }
            this.propertyInfo = property3.substring(charPos);
            return;
        }
        this.subminorVersion = 0;
        this.minorVersion = 0;
        this.majorVersion = 0;
        this.propertyInfo = property2;
    }

    VersionedStringProperty(String property, int major, int minor, int subminor) {
        this.preferredValue = false;
        this.propertyInfo = property;
        this.majorVersion = major;
        this.minorVersion = minor;
        this.subminorVersion = subminor;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public boolean isOkayForVersion(Connection conn) throws SQLException {
        return conn.versionMeetsMinimum(this.majorVersion, this.minorVersion, this.subminorVersion);
    }

    public String toString() {
        return this.propertyInfo;
    }
}
